# InvestigationPlaybookTasksAPI

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**ancestors** | **list[str]** |  | [optional] 
**inc_severity** | [**Severity**](Severity.md) |  | [optional] 
**inv_id** | **str** |  | [optional] 
**inv_name** | **str** |  | [optional] 
**task** | [**InvestigationPlaybookTask**](InvestigationPlaybookTask.md) |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


